The core GEDCOM data representation language may be used to represent any form of structured information, not just genealogical data, using a sequential stream of characters.
Structs
- Error
- Represents an error with reading a GEDCOM file.
- Item
- Represents an efficient, extendable string.
- Line
- Represents an entire line or record in the GEDCOM data format.
- Record
- Represents a logical record in the GEDCOM data format.
Enums
- Value
- Represents a line value, either a pointer or item.